@@ -244,7 +244,7 @@ DEFAULT_NAMING_SCHEME = "([A-Z]+|[A-Z][a-z]*)(_([A-Z]+|[A-Z][a-z]*|[0-9]+))*"
 # Underscore-separated acronyms or capitalised words. For example
 # "Kitten_Class" or "LASER", but not "potatoFarmer".
 
-DEFAULT_METHOD_NAMING_SCHEME = "[a-z]+(_[a-z]+)*"
+DEFAULT_LC_NAMING_SCHEME = "[a-z]+(_[a-z]+)*"
 # A much simpler naming scheme: underscore separated lowercase without
 # numbers.
 
@@ -271,10 +271,11 @@ STYLE_RULES = {
                 ["docstring", "file_header"]),
             "copyright_regex": Copyright_Regex_Style_Configuration(
                 ("Regex for picking out copyright notice. Must include "
-                 "named groups: 'ystart', 'yend', and 'org'"),
-                default = (r"(\(c\) )?Copyright "
-                           r"((?P<ystart>\d\d\d\d)(-| - ))?(?P<yend>\d\d\d\d)"
-                           r"( by)? *(?P<org>.*)")),
+                 "named groups: 'copy', 'ystart', 'yend', and 'org'"),
+                default =
+                (r"(?P<copy>(Copyright \([cC]\))|((\([cC]\) )?Copyright)) "
+                 r"((?P<ystart>\d\d\d\d)(-| - ))?(?P<yend>\d\d\d\d)"
+                 r"( by)? *(?P<org>.*)")),
             "copyright_entity": Set_Style_Configuration(
                 "Valid copyright holder."),
             "copyright_primary_entity": String_Style_Configuration(
@@ -368,7 +369,15 @@ STYLE_RULES = {
                 default = DEFAULT_NAMING_SCHEME),
             "regex_method_name" : Regex_Style_Configuration(
                 "Regex for class method names",
-                default = DEFAULT_METHOD_NAMING_SCHEME)
+                default = DEFAULT_LC_NAMING_SCHEME)
+        }),
+
+    "naming_parameters" : Style_Rule(
+        "Checks names of function and method parameters.",
+        {
+            "regex_parameter_name" : Regex_Style_Configuration(
+                "Regex for parameter names",
+                default = DEFAULT_LC_NAMING_SCHEME)
         }),
 
     "naming_classes" : Style_Rule(
@@ -379,6 +388,14 @@ STYLE_RULES = {
                 default = DEFAULT_NAMING_SCHEME)
         }),
 
+    "naming_enumerations" : Style_Rule(
+        "Checks names of enumerations.",
+        {
+            "regex_enumeration_name" : Regex_Style_Configuration(
+                "Regex for parameter names",
+                default = DEFAULT_NAMING_SCHEME)
+        }),
+
     "indentation" : Style_Rule(
         "Make indentation consistent.",
         {
